Plover Stenograph USB
=====================

Use Stenograph machines such as the Luminex, Diamanté, and Protégé on Plover. The plugin may
not work with other machines.

Special thanks to Keith McCready for his guidance and support.

Tested Machines
---------------

If you test another machine, please let me know whether it works or not.

- Working
  - Luminex
  - Diamanté
  - Protégé
- Not Working
  - Unknown

Get the Drivers
---------------

-  On Windows, install the `Stenograph USB Drivers`_ (`direct link`_)
-  On Mac, install `libusb`_
-  On Linux, ensure you have libusb installed

Installation
------------

The plugin is available to install from within Plover 4 using the
Plugins Manager.

.. _Stenograph USB Drivers: http://www.stenograph.com/utilities-links-downloads
.. _direct link: http://www.stenograph.com/content/files/documents/USB_Writer_Drivers.zip
.. _libusb: http://macappstore.org/libusb/
